class SmallReasonForBan(Exception): pass
class AccountNotFoundInDotenv(Exception): pass
class InvalidDotenvKeys(Exception): pass
class CommandIsntAsync(Exception): pass
class EventIsntAsync(Exception): pass
class InvalidChatChoice(Exception): pass
class InvalidEvent(Exception): pass
class InvalidFileType(Exception): pass
class InvalidReturn(Exception): pass
class AminoSays(Exception): pass